Update options

Using a single server for the SSD does not provide redundancy. Therefore, upgrading to a new version without interrupting traffic is not possible.
There are two ways to upgrade.

The first option is to stop traffic and update PostgreSQL and all ecss packages on the working SSD, then activate the service and start traffic. The advantage of this option is a simple upgrade process. The disadvantage is a longer traffic interruption.

The second option is to perform a complete fresh installation of the OS on a separate host (physical or virtual), and then install the SSD using temporary IP addresses. During the installation, you will also need to copy the databases (Mnesia + PostgreSQL) from the old host to the new one. Once the new SSD is installed, the temporary IP addresses are replaced with those of the old SSD (at this point, the old SSD is disabled) and the MSR files are configured. After this, the new SSD begins serving traffic. The advantage of this option is minimal traffic interruption. The disadvantage is a more complex and time-consuming update procedure.

Select the appropriate option.


ECSS-10 version 3.17 supports two licensing types: file-based licenses (with or without a token) and ELM licenses. Depending on the licensing type, different commands will be executed during the update.

You can check which type is used on your SWS using the following command:


/cluster/storage/ds1/licence/list-licence 

When using a file license, the output will be:

/cluster/storage/ds1/licence/list-licence
┌──┬───────────────────┬────────────┬──────┬───────────────────┬────────────────────┬────────────┐
│Id│Creation date(UTC) │   SSW ID   │Active│    Description    │Expiration date(UTC)│ Time left  │
├──┼───────────────────┼────────────┼──────┼───────────────────┼────────────────────┼────────────┤
│1 │31.10.2025 14:16:00│ECSS 010070 │*     │Eltex SC softswitc │31.12.2026 23:59:59 │224d 21h 31m│
│0 │                   │ECSS DEFAULT│      │Default licence    │                    │            │
└──┴───────────────────┴────────────┴──────┴───────────────────┴────────────────────┴────────────┘

When using an ELM license, the output will be:

/cluster/storage/ds1/licence/list-licence                  
┌──┬───────────────────┬────────────┬──────┬────────────────┬────────────────────┬────────────┐
│Id│Creation date(UTC) │   SSW ID   │Active│  Description   │Expiration date(UTC)│ Time left  │
├──┼───────────────────┼────────────┼──────┼────────────────┼────────────────────┼────────────┤
│1 │02.12.2025 13:51:39│ECSS2000000 │*     │ECSS ELM License│02.12.2026 13:51:39 │364d 11h 47m│
│0 │01.01.1990 00:00:00│ECSS DEFAULT│      │Default licence │                    │            │
└──┴───────────────────┴────────────┴──────┴────────────────┴────────────────────┴────────────┘




Before performing the update procedure, perform a full backup.

If you need the latest billing data, you need to finalize the current CDR and download the CDR files to a remote server:

/domain/test_domain/cdr/make_finalize_cdr 
Created file(s): cdr_20260522_11_51_16_1_c.csv

First option

  1. Perform a full backup
  2. You need to mask all nodes on the server and disable node autostart:
    sudo systemctl mask --now ecss-ds ecss-mycelium ecss-mediator ecss-core ecss-pa-sip ecss-sorm

    When the attached command is executed, a notification will be displayed.

    Warning: The unit file, source configuration file or drop-ins of ecss-ds.service changed on disk. Run 'systemctl daemon-reload' to reload units.
    Warning: The unit file, source configuration file or drop-ins of ecss-mycelium.service changed on disk. Run 'systemctl daemon-reload' to reload units.
    Warning: The unit file, source configuration file or drop-ins of ecss-mediator.service changed on disk. Run 'systemctl daemon-reload' to reload units.
    Warning: The unit file, source configuration file or drop-ins of ecss-core.service changed on disk. Run 'systemctl daemon-reload' to reload units.
    Warning: The unit file, source configuration file or drop-ins of ecss-pa-sip.service changed on disk. Run 'systemctl daemon-reload' to reload units.

    These messages are not errors. Continue with the procedure.

  3. Update the ssw repository:
    sudo sh -c "echo deb [arch=amd64]  http://archive.eltex.org/ssw/jammy/3.18 stable main extras external > /etc/apt/sources.list.d/eltex-ecss10-stable.list"
  4. Perform package update:
    sudo apt update

    If you see this system message:

    W: http://archive.eltex.org/ssw/jammy/3.18/dists/unstable/InRelease: Key is stored in legacy trusted.gpg keyring (/etc/apt/trusted.gpg), see the DEPRECATION section in apt-key(8) for details.

    Run the following command:

    sudo cp /etc/apt/trusted.gpg /etc/apt/trusted.gpg.d


  5. Updating PostgreSQL:
    1. Turn off the Docker container:
      sudo docker compose -f /srv/ecss/ecss-postgres-bdr-ssw/docker-compose.container.yml down

       sudo docker compose -f /srv/ecss/ecss-postgres-bdr-ssw/docker-compose.container.yml down
      [+] down 2/2
       ✔ Container ecss-postgres-bdr-ssw-postgres-container-1 Removed                                                                                                                           
       ✔ Network ecss-postgres-bdr-ssw_default                Removed 
    2. Remove the old deb package, since the upgrade option is not supported:
      sudo apt remove ecss-postgres-bdr-ssw

      Run remove, not purge, because remove preserves the volumes directory with our database tables.


      sudo apt remove ecss-postgres-bdr-ssw
      Reading package lists... Done
      . . .
      The following packages will be REMOVED:
        ecss-postgres-bdr-ssw
      . . .
      Do you want to continue? [y/n] y
      Deleting ecss-postgres-bdr-ssw (17.1.0.59+ssw) …
    3. Install a new deb package:
      sudo apt install ecss-postgres-bdr-ssw 

      During installation, you will be asked the same questions as during the initial installation:

      The answers must exactly match those specified in the procedure, otherwise an attempt will be made to create a new database and the installation will fail.

      QuestionReplyExample

      The current IP address of the network interface.


      10.0.10.41 (select)

      Install on a cluster?

      Select <Yes> if the package is installed on a cluster node.

      No (select)


      sudo apt install ecss-postgres-bdr-ssw
      . . .
      ==================
       Create databases 
      ==================
      Database ecss_storekeeper_db already exists, skipping...
      Database web_conf already exists, skipping...
      Extension btree_gist already exists, skipping...
      Extension bdr already exists, skipping...
      
      ===================================
       Creating Postgres Exporter Schema 
      ===================================
      Node IP: localhost
      psql:/srv/ecss/ecss-postgres-bdr-ssw/schema.sql:1: NOTICE:  schema "postgres_exporter" already exists, skipping
      CREATE SCHEMA
      GRANT
      CREATE FUNCTION
      CREATE VIEW
      GRANT
      CREATE FUNCTION
      CREATE VIEW
      GRANT
      psql:/srv/ecss/ecss-postgres-bdr-ssw/schema.sql:28: NOTICE:  extension "pg_stat_statements" already exists, skipping
      CREATE EXTENSION
      CREATE FUNCTION
      CREATE VIEW
      GRANT
      . . .
      =======================================================
      =======================================================
       ecss-postgres-bdr-ssw successfully installed/updated! 
      =======================================================
      =======================================================
      
      
      ┏┓┏┓┏┓┏┳┓┏┓┳┓┏┓┏┓  ┳┓┳┓┳┓  ┏┓┏┓┓ ┏
      ┃┃┃┃┗┓ ┃ ┃┓┣┫┣ ┗┓  ┣┫┃┃┣┫  ┗┓┗┓┃┃┃
      ┣┛┗┛┗┛ ┻ ┗┛┛┗┗┛┗┛  ┻┛┻┛┛┗  ┗┛┗┛┗┻┛
    4. After installation, check that the new image has been pulled in and Docker has started by running the command:
      sudo docker ps

      sudo docker ps
      CONTAINER ID   IMAGE                                           COMMAND                  CREATED              STATUS              PORTS                                         NAMES
      bf73743d3e09   git.eltex.loc:4567/ecss/ecss-postgresbdr:3.18   "/docker-entrypoint.…"   About a minute ago   Up About a minute   0.0.0.0:5439->5432/tcp, [::]:5439->5432/tcp   ecss-postgres-bdr-ssw-postgres-container-1
  6. Updating the ecss-dns-env package:
    sudo apt install ecss-dns-env

    After the update, you need to update the configuration by running the command. The answers to the questions are similar to the installation procedure:
    sudo dpkg-reconfigure ecss-dns-env
  7. Update the ecss-user package:

    When updating, you need to apply new configuration files (confirm with -Y).


    sudo apt install ecss-user
  8. Update the ecss-utils package:
    sudo apt install ecss-utils
  9. Install the License Provider package:

    sudo apt install ecss-license-provider

    When installing the ecss-license-provider package the following questions will be asked:

    QuestionsAnswersExamples

    License Provider listen ip:

    0.0.0.0 (default value)

    License Provider listen port:4321 (default value)

    Log level:info (default value),
    possible options: debug, error, info

    License Provider cluster key:

    specify a unique name
    ecss-lm-cluster (default value)

    Managers with the same names will attempt to form a cluster for mutual redundancy.


    What services should be restarted?

    ecss-license-provider.service (default value)

    The data is saved to the /etc/ecss/ecss-license-provider/config.env file:

    ECSS_LM_HOST=0.0.0.0
    ECSS_LM_PORT=4321
    ECSS_LM_LOG_LEVEL=info
    RELEASE_COOKIE=ecss-abf-lm-cluster

    Configuring License Provider (LP)

    The ecss-license-provider service uses two configuration files: /etc/ecss/ecss-license-provider/config.env and /etc/ecss/ecss-license-provider/config.yaml.

    The information is saved to the config.env file when the ecss-license-provider is installed.

    The config.yaml file contains general settings for connecting to the ELM server and information about licenses: what licenses to take, where to take them from, and where to send them, all this information should be configured manually.

    elm_addresses: []
    licenses: []
    ecss_nodes: []
    To fill out these fields, open the ecss-elm-adapter configuration file used in the version 3.17 /etc/ecss/ecss-elm-adapter/config.env:
    cat /etc/ecss/ecss-elm-adapter/config.env 
    ELM_HOST=elm.eltex-co.ru
    ELM_PORT=8099
    ECSS_PRODUCT_ID=ECSS2000000
    ECSS_LICENSE_KEY=ssw987654
    LOG_LEVEL=info
    LICENCE_FAIL_TIMER_SECONDS=10
    LICENCE_PULL_TIMER_SECONDS=360

    In the elm_addresses field, you must specify a list of ELM servers to which you want to connect to obtain licenses. First address in the list is used as the main one. Additional lines contain backup addresses.
    Example:
    - "elm.eltex-co.ru:8099"
    - "192.168.111.22:8099"
    - "elm-3.eltex.loc:8099"

    Then licenses in the licenses field are specified.

    • The id can be anything, as long as it is unique for each license. It only affects the license address on the License Provider itself (e.g., 0, 1, 2, 3).
    • kind. For SSW, only SSW (in uppercase) is supported.
    • type is set to elm if this license is to be requested from the ELM server. If you need to use an SSW file-based license, set the type to ecss_license.
      • For the elm type, you must specify the license_key and product_id fields to identify the license.
      • For the ecss_license type, specify the license field, which contains the static license key.

    license_key = ECSS_LICENSE_KEY and product_id = ECSS_PRODUCT_ID parameters must match the data previously uploaded to the ELM server.

    ecss_nodes block.

    You must specify the details of the services that will receive the license. A service is defined by three parameters:

    • id - the service identifier. In the case of SSW, this must match the ECSS_ID of the SSW being licensed.
    • kind - the type of service being licensed. As with the licenses block, the SSW and AUP types are supported. For SSW, only the SSW type is supported.
    • license_id - the identifier of the license that will be sent to this service. It corresponds to the license identifiers from the licenses block

    Two SSWs with different ECSS_IDs cannot receive the same license; a configuration with such an assignment will be marked as invalid.
    Additionally, two SSWs with identical ECSS_IDs cannot simultaneously obtain the same license from a single License Provider; therefore, it is extremely important to set your ECSS_ID correctly and ensure it is unique, at least within the scope of the License Provider being used.

    ECSS_ID format.
    It must begin and end with a Latin letter or a digit; periods and dashes may be used within the string.

    [A-Za-z0-9][A-Za-z0-9.-][A-Za-z0-9]
    elm_addresses:
     - "elm.eltex-co.ru:8099"
    licenses:
     - id: 0
       kind: SSW
       type: elm
       license_key: "ssw987654"
       product_id: "ECSS2000000"
    ecss_nodes:
     - id: eltex1.test
       kind: ssw
       license_id: 0

    Restart the ecss-license-provider.service service to up date the configuration from the /etc/ecss/ecss-license-provider/config.yaml file via the following command:

    sudo systemctl restart ecss-license-provider.service
  10. Update the ecss-node package:
    sudo apt install ecss-node

    During installation, you will be prompted to configure the settings required to generate the configuration files; examples of possible answers are provided below.

    ecss-node questionsAnswers for ecss1Example

    Cookies for the core node:

    ecss-core (default value)

    It is recommended to replace this with a unique value

     


    Cookies for the ds node

    ecss-ds (default value)

    It is recommended to replace this with a unique value

     


    Cookies for the mediator node:

    ecss-mediator (default value)

    It is recommended to replace this with a unique value

     


    Cookies for the pa-sip node:

    ecss-pa-sip (default value)

    It is recommended to replace this with a unique value

     


    Cookies for the mycelium node:

    ecss-mycelium (default value)

    It is recommended to replace this with a unique value

     


    Use the current version of the configuration file?

    No (default value)


    When updating, you must apply the new configuration files (confirm with -Y).

     

  11. Enable the nodes.
    Enable the SSW services using the following commands: 
    sudo systemctl unmask ecss-ds ecss-mycelium ecss-mediator ecss-core ecss-pa-sip ecss-sorm

    sudo systemctl enable ecss-ds ecss-mycelium ecss-mediator ecss-core ecss-pa-sip ecss-sorm
  12. Starting SSW on ecss1. Start the following services:
    ecss-mycelium
    sudo systemctl start ecss-mycelium
    ecss-ds
    sudo systemctl start ecss-ds
    ecss-core
    sudo systemctl start ecss-core
    ecss-mediator
    sudo systemctl start ecss-mediator

    Do not start PA-SIP yet

  13. Check the status of services by running the system-status command in CoCon:
    /system-status 
    Checking...
    ┌─┬───────────────┬────────────────────────┬───────────────┬────────────┬──────┐
    │ │     Node      │        Release         │ Erlang nodes  │Mnesia nodes│Uptime│
    ├─┼───────────────┼────────────────────────┼───────────────┼────────────┼──────┤
    │ │core1@ecss1    │ecss-core-3.18.0.271    │core1@ecss1    │not running │14m 4s│
    │ │ds1@ecss1      │ecss-ds-3.18.0.271      │ds1@ecss1      │ds1@ecss1   │14m 4s│
    │ │md1@ecss1      │ecss-mediator-3.18.0.271│md1@ecss1      │md1@ecss1   │14m 4s│
    │ │mycelium1@ecss1│ecss-mycelium-3.18.0.271│mycelium1@ecss1│not running │14m 4s│
    │ │sorm1@ecss1    │ecss-sorm-3.18.0.271    │sorm1@ecss1    │not running │14m 5s│
    └─┴───────────────┴────────────────────────┴───────────────┴────────────┴──────┘
    
    All services are started.
    
      Active media resource selected list specific:
    ┌─────────────┬───────────┬────────────┬───────────┬───────────┐
    │    Node     │    MSR    │    MSR     │ Cc-status │ Cc-uptime │
    │             │           │  version   │           │           │
    ├─────────────┼───────────┼────────────┼───────────┼───────────┤
    │ core1@ecss1 │ msr.ecss1 │ 3.17.1.1.7 │ connected │ 00:43:03  │
    └─────────────┴───────────┴────────────┴───────────┴───────────┘
  14. Licensing modes.

    No additional actions are required.

    /cluster/storage/ds1/licence/list-licence
    ┌──┬───────────────────┬────────────────┬──────┬────────────────────────────────────────────┬────────────────────┬────────────┐
    │Id│Creation date(UTC) │     SSW ID     │Active│                Description                 │Expiration date(UTC)│ Time left  │
    ├──┼───────────────────┼────────────────┼──────┼────────────────────────────────────────────┼────────────────────┼────────────┤
    │1 │31.10.2025 14:16:00│ECSS 010070     │*     │Eltex SC softswitch                         │31.12.2026 23:59:59 │224d 21h 31m│
    │0 │                   │ECSS DEFAULT    │      │Default licence                             │                    │            │
    └──┴───────────────────┴────────────────┴──────┴────────────────────────────────────────────┴────────────────────┴────────────┘
  15. Configure the SSW connection to the License Provider using the following command in CoCon (in this example, the License Provider is installed in the ecss1 host, hosts' IPadd is 10.0.10.41. The default port value from the/etc/ecss/ecss-license-provider/config.env file is 4321)

    /system/licence/manager/set --hosts [https://10.0.10.41:4321]

    After execution, check the connection status with the following command:

    /system/licence/manager/show-status
    ┌───────────────────────┬───────┬─────┐
    │         Host          │Current│Alive│
    ├───────────────────────┼───────┼─────┤
    │https://10.0.10.41:4321│*      │true │
    └───────────────────────┴───────┴─────┘

    Teh host should have a status of alive=true and be “current.”  

    • Current - indicates which host the SSW is connected to. If there is a connection, * is displayed; if not, nothing is displayed.
    • Alive - displays the host’s availability status (healthcheck).

    A lack of connection to the License Provider or ELM is equivalent to a lack of access to the token, which will lead to critical failures and a transition to emergency mode; after a certain period, if the connection is not restored, the system will switch to the Default license.

    This behavior applies only when operating in ELM mode.

    If the status for one of the License Provider hosts is shown as “current,” you can send a request to upload the license to the SSW using the following command:

    /cluster/storage/ds1/licence/request
    /cluster/storage/ds1/licence/request      
    Licence received      
    [*******                                                               ] 6s 2ms   
    Success: Licence parameters applied
    /cluster/storage/ds1/licence/list-licence 
    ┌──┬───────────────────┬────────────┬──────┬────────────────┬────────────────────┬────────────────────┬─────────┐
    │Id│Creation date(UTC) │   SSW ID   │Active│  Description   │Comm. Exp. Date(UTC)│Expiration date(UTC)│Time left│
    ├──┼───────────────────┼────────────┼──────┼────────────────┼────────────────────┼────────────────────┼─────────┤
    │1 │14.04.2026 11:18:34│ECSS2000000 │*     │ECSS ELM License│09.04.2027 16:26:34 │06.06.2026 10:49:12 │1d 6h 59m│
    │0 │01.01.1990 00:00:00│ECSS DEFAULT│      │Default licence │                    │                    │         │
    └──┴───────────────────┴────────────┴──────┴────────────────┴────────────────────┴────────────────────┴─────────┘


  16. Updating the ecss-restfs package.

    Accept all new configuration files by choosing Y.


    sudo apt install ecss-restfs
  17. Updating the ecss-media-server package.

    The Media Server analyzes the configuration in the files located in the /etc/ecss/ecss-media-server/ directory. Version 3.17 introduces a new feature for managing codec priorities. If, for any reason, multiple files contain a codec section that lists the same codec more than once, a conflict will occur after the update, and the Media Server will not function.

    Therefore, there should be no conflicts regarding codec priorities in the configuration files of a single Media Server (there should be only one entry for one codec, and it should not be repeated in other files). The decision regarding which specific files need to be configured is left to the discretion of the system administrator.

    Perform an update:

    Accept all new configuration files by choosing Y.


    sudo apt install ecss-media-server
    Update the configuration:
    sudo dpkg-reconfigure ecss-media-server
  18. Updating the ecss-media-resources package
    sudo apt install ecss-media-resources
  19. Updating the ecss-web-conf package
    sudo apt install ecss-web-conf
  20. Updating the ecss-teleconference-ui package.

    sudo apt install ecss-teleconference-ui

    Updating the ecss-crm-server package.

    sudo apt install ecss-crm-server

    Updating the ecss-cc-ui package.

    sudo apt install ecss-cc-ui

    Updating the ecss-call-api package.

    sudo apt install ecss-call-api

    Updating the ecss-peeper-client package.

    sudo apt install ecss-peeper-client
  21. Launch ecss-pa-sip:
    sudo systemctl start ecss-pa-sip
    Check the status of services by running the /system-status command:
    /system-status 
    Checking...
    ┌─┬───────────────┬────────────────────────┬───────────────┬────────────┬───────┐
    │ │     Node      │        Release         │ Erlang nodes  │Mnesia nodes│Uptime │
    ├─┼───────────────┼────────────────────────┼───────────────┼────────────┼───────┤
    │ │core1@ecss1    │ecss-core-3.18.0.271    │core1@ecss1    │not running │54m 27s│
    │ │ds1@ecss1      │ecss-ds-3.18.0.271      │ds1@ecss1      │ds1@ecss1   │54m 27s│
    │ │md1@ecss1      │ecss-mediator-3.18.0.271│md1@ecss1      │md1@ecss1   │54m 27s│
    │ │mycelium1@ecss1│ecss-mycelium-3.18.0.271│mycelium1@ecss1│not running │54m 27s│
    │ │sip1@ecss1     │ecss-pa-sip-3.18.0.271  │sip1@ecss1     │sip1@ecss1  │54m 27s│
    │ │sorm1@ecss1    │ecss-sorm-3.18.0.271    │sorm1@ecss1    │not running │54m 27s│
    └─┴───────────────┴────────────────────────┴───────────────┴────────────┴───────┘
    
    All services are started.
    
      Active media resource selected list specific:
    ┌─────────────┬───────────┬──────────┬───────────┬───────────┐
    │    Node     │    MSR    │   MSR    │ Cc-status │ Cc-uptime │
    │             │           │ version  │           │           │
    ├─────────────┼───────────┼──────────┼───────────┼───────────┤
    │ core1@ecss1 │ msr.ecss1 │ 3.18.0.7 │ connected │ 00:01:17  │
    └─────────────┴───────────┴──────────┴───────────┴───────────┘
    Verify that active registrations have been migrated to the updated host. To do this, check the registered subscribers on SSW. Execute the following command in CoCon:
    /domain/test_domain/sip/user/registered sip *            
    450 make users list ...
    [**********************************************************************] 28mks    
    450 users information read ...
    [**********************************************************************] 1ms      
    Executed on the sip1@ecss1
    ┌───────────────┐
    │ elements: 436 │
    └───────────────┘
  22. After the update is complete, verify that all SSW services are functioning properly.

Second option

Initial data
Use temporary IP addresses during installation (10.0.10.51/10.0.20.51 in the example). In the final steps, the temporary addresses will be replaced with the actual IP addresses for SSW version 3.17 (10.0.10.41/10.0.20.41 in the example).

Initial data

Integration of the ECSS-10 (SSW) Class 5 software switch on a single physical server with SIP support is required, with the following load parameters:

  • Maximum number of subscribers – 15000 (MUL Max user limit);
  • Maximum number of concurrent connections – 2000 (MCL Max call limit);
  • System redundancy is not required;
  • Number of Ethernet network interfaces – 4.

According to the technical specifications, the hardware platform must be determined.

Device

Required resource

Hardware product series

MCL

MUL

Server 1

2500

15000

Heavy

After defining the project requirements, create a preliminary network diagram.

Example of how components are distributed across the address space for a single node:

Server (host) name

Role 

Interface

Address

Your project's address

Port

Static addresses of the software switch

ecss1

Server address

net.10 (mgm)

10.0.10.51/24


-

ecss1

Protocol adapter address

net.20 (voip)

10.0.20.51/24


-

ecss1

Gateway address

net.10 (mgm)

10.0.10.1
-

ecss1

DNS servers addresses

net.10 (mgm)

10.0.10.1, 8.8.8.8
-

Internal addresses of the software switch

ecss1

Core address (ecss-core)

lo

127.0.0.1/24


5000

ecss1

Media server address (ecss-media-server (MSR))

lo

127.0.0.1/24


5040



Connecting to the network

To ensure redundancy, it is recommended to use two switches when configuring the server’s network topology.

Figure 1 – Network connection diagram

Option 1. Active-backup configuration

The switches are interconnected in an ERPS ring.

All four physical network interfaces are combined into a single aggregated link (bond). The server’s port aggregation is configured in active-backup mode, meaning that only one network interface is active at any given time. The server’s network interfaces are connected in pairs to the switches, on which the port aggregation (port-channel) is also configured in active-backup mode.

For example, eth1 and eth2 are connected to the first switch, while eth3 and eth4 are connected to the second.


Option 2. LACP diagram

The switches are linked together in a stack. The stack must function logically as a single switch capable of providing port aggregation in LACP mode across different physical switches. An example is the MES3124 switches with specialized firmware.

All four physical network interfaces are also combined into a single aggregated link (bond). Server port aggregation is configured in 802.3ad mode. Aggregated groups of network cards with the same speed and duplex settings are created. With this configuration, data transmission utilizes all channels in the active aggregation in accordance with the IEEE 802.3ad standard. The choice of which interface to send a packet through is determined by a policy. By default, this is the XOR policy; the “xmit_hash” policy can also be used.

Requirements:

  • Ethtool support in the driver to retrieve information about the speed and duplex settings on each network interface;
  • Support for the IEEE 802.3ad standard on the switch;

The server’s network interfaces are also connected in pairs to switches on which port aggregation (port-channel) is configured in LACP mode. For example, eth1 and eth2 are connected to the first switch (port-channel 1), and eth3 and eth4 are connected to the second (port-channel 2).

Installing the OS

The SSW ECSS10 installation consists of two main parts:

  • Preparation – Installing Ubuntu 22.04, updating Ubuntu packages, "optimizing" the OS, installing additional software packages, configuring network interfaces, /etc/hosts, and ssh-keygen

  • Installation of Eltex ECSS10 applications

Preparation phase

This section describes the installation of the operating system, as well as the required and additional packages. The ECSS-10 system, version 3.17, runs on Ubuntu 22.04.

Prerequisites

  • Bootable installation medium containing the operating system installation package;
  • A prepared server with an updated BIOS and ILO (if available) and a network connection for Internet access;
  • First boot priority set to the installation media – USB flash drive or CD/DVD in the BIOS;
  • Sufficient disk space and memory as specified by the project.

OS installation

To install the OS, perform the following steps:

  • After booting from the installation medium, select "Install Ubuntu Server".
  • Select the system language and keyboard layout.
  • Configure the network interface to connect to the Internet:

  • Create disk partitions according to Table 1
  • Set the server and user names
  • Install the OpenSSH server
  • Reboot the successfully installed OS



Table 1 – Option for storing information in the file system on physical storage media for servers

1Operating system boot partition (created automatically)bootraid 1:hdd1, hdd2boot/bootext41 GbPrimary
2Operating system root partitionrootraid 1:hdd1, hdd2root/ext430 GbLogical
3Local database informationmnesiaraid 1:hdd1, hdd2mnesia/var/lib/ecssext410 GbLogical
4Distributed database for storing media resourcesglusterfsraid 1:hdd1, hdd2 or hdd3glusterfs/var/lib/ecss/restfsext4Max GbLogical
5OS subsystem operation logslograid 1:hdd1, hdd2 or hdd3log/var/logext420 GbLogical
6ECSS subsystem operation logsecss_lograid 1:hdd1, hdd2 or hdd3ecss_log/var/log/ecssext420 GbLogical
7Databasesecss_dbraid 1:hdd1, hdd2 or hdd3ecss_db/srv/ecss/ecss-postgres-bdr-ssw/ext4100–400 Gb*Logical
8User fileshomeraid 1:hdd1, hdd2 or hdd3home/homeext410 GbLogical


The recommended value for the Light, Light+, and Midi series is 100 Gb. The recommended value for the Heavy series is 200 Gb, and for the Super Heavy series, 400 Gb.

At least 256 Gb of free space is required for the system to operate.

The "hostname" parameter must be configured on the system's servers.

It is recommended to use the same username (any name except ssw) on all system servers. The ECSS-10 license is tied to the eToken/ruToken key and the computer name (hostname). The system user ssw is created during installation of the ecss-user package.

If a single server is used, the recommended hostname value is ecss1;


Network configuration

We will configure the network according to the parameters specified in the technical specifications. In this example, we assume that the required operating system is already installed. 

It is recommended to separate traffic used for different purposes – for example, management traffic and VoIP traffic. To do this, create two or more VLANs. With a light load, you can get by with a single VLAN for simplicity, but this will cause inconvenience in the future when capturing and analyzing traffic dumps. In accordance with the technical specifications, the host’s IP addresses, gateways, DNS, and routing to other networks are configured on the VLANs.

In this example, according to the technical specifications, we will use the following addresses:

  • 10.0.10.51/24 — for management, vlan 10;
  • 10.0.20.51/24 — for VoIP.

Within the server platform, there is an addressing structure, and internal addresses are used for communication between subsystems (nodes) in the cluster. For example, the internal address for a cluster on a single server is 127.0.0.1, and the core (ecss-core) communicates with the multimedia data processing server (ecss-media-server). They communicate using the same address, but each software component has its own transport port: 5000 for ecss-core, 5040 for ecss-msr.

A single address is defined for all cluster nodes to access the database, for example, 127.0.0.1. This ensures consistency, whereby all cluster nodes have exactly the same data about the current state of the software switch’s dynamic components (for example, call history).

Preparing system's network interfaces

According to technical specifications, the system has 4 network interfaces. Information about their state can be looked up using the ifconfig or ip a command:

eth0: flags=6211<UP,BROADCAST,RUNNING,SLAVE,MULTICAST> mtu 1500
ether 36:10:28:73:63:01 txqueuelen 1000 (Ethernet)

eth1: flags=6211<UP,BROADCAST,RUNNING,SLAVE,MULTICAST> mtu 1500
ether 36:10:28:73:63:01 txqueuelen 1000 (Ethernet)

eth2: flags=6211<UP,BROADCAST,RUNNING,SLAVE,MULTICAST> mtu 1500
ether be:77:ea:52:4d:39 txqueuelen 1000 (Ethernet)

eth3: flags=6211<UP,BROADCAST,RUNNING,SLAVE,MULTICAST> mtu 1500
ether be:77:ea:52:4d:39 txqueuelen 1000 (Ethernet)

lo: flags=73<UP,LOOPBACK,RUNNING> mtu 65536
inet 127.0.0.1 netmask 255.0.0.0

First, configure the network interfaces. In Ubuntu 22, the netplan utility is used to configure them.

This utility makes it possible to configure the network settings and then load them into the system using the "networkd" or "NetworkManager" network manager.

sudo nano /etc/netplan/ecss_netplan.yaml


All other files in this directory must be moved to another location or deleted.

In the configurations for each host, we first define the ethernets section, which describes the Ethernet interfaces present in the system that will be used later. For each interface, you must disable dynamic address assignment (DHCP). 

Next, configure the VLANs, where you can optionally specify gateways for communication with the outside world and DNS server addresses, as well as the IP addresses for each interface.

Please note that when editing netplan, it is necessary to follow YAML indentation rules:

  • There must be at least two spaces before each line (except for network);
  • Each subsection is additionally separated by 2 spaces:

→  Section                                                                   |network

→  Subsection                                                             |_'_'bonds:

→  Subsection describing the "bonds" section           |_'_'_'_'bonded_one:

→  etc.                                                                         |_'_'_'_'...

  • There is no space before the ":" character, and one space after it;
  • Before the "-" character, there are as many spaces as if a new subsection were starting, and one space after it.

Example of configuring the ecss_netplan.yaml file for the “active-backup” option

# Netplan for the ecss1 host of the software switch
# Please note that there must be at least two spaces in every line and section (except for the network section).

network:
  version: 2 # netplan version
  renderer: networkd # netplan configuration renderer
  ethernets: # Section describing Ethernet interfaces
    enp0s3: # Name of the virtual machine’s interface to the Internet
        dhcp4: no # Disable dynamic IP address assignment on interfaces
        dhcp6: no
        addresses: [192.168.56.51/24]
    enp0s8: # Name of the interface for SSW
        dhcp4: no # Disable dynamic IP address assignment on interfaces
        dhcp6: no
  vlans:
    net.10: # Management interface
        id: 10
        link: enp0s3
        addresses: [10.0.10.51/24]
    net.20: # VoIP interface
        id: 20
        link: enp0s8
        addresses: [10.0.20.51/24]

The following bonds settings are required for the ECSS server to ensure that configuration works correctly:

mode: active-backup – specifies the operating mode in which one of the links is selected as active, while the others remain in standby;
primary-reselect-policy: failure specifies that a new active link should be selected only when the current active link enters a failure state. This helps avoid unnecessary switchover;
gratuitous-arp: 5 when the active link changes, five gratuitous ARP requests are sent to the switch to update its forwarding table. This facilitates faster switching;
all-slaves-active: true forces the system to accept incoming frames on backup interfaces. Thus, traffic balancing on the MES does not interfere with operations. Data is sent to the server over all links, while the server sends data only over the active link;
mii-monitor-interval: 100 enables link monitoring via the MII interface and sets the polling interval to 100 ms;
up-delay: 1000 specifies that an interface that is up should not be considered available immediately, but rather after a one-second delay following the interface’s activation. This is necessary to avoid unnecessary switching in cases where the port “flips” several times between the “on” and “off” states.

It is also recommended to check that there are no other files in the /etc/netplan/ directory; if any other files are present, they must be moved to a different directory or deleted, otherwise network interfaces may be configured incorrectly and SSW may not function properly.

Apply the configured settings using the following command:

sudo netplan apply

On the system’s servers, you must configure the “hostname” parameter.

It is recommended to use the same username (any name except ssw) on all system servers. The ECSS-10 license is tied to the eToken/ruToken key and the computer name (hostname), so you must use the standard values. The ssw system user is created during installation of the ecss-user package.

If a single server is used, the recommended hostname value is ecss1;
Other hostnames are possible only upon project approval; this is required for license generation.

Specify the hostname as ecss1 in the /etc/hostname file:

sudo nano /etc/hostname 

Specify the actual IP address and the hostname currently in use (for example, 10.0.10.51 ecss1) in the /etc/hosts file:

127.0.0.1   localhost # Local loopback address, used by some ECSS services
10.0.10.51  ecss1 # Host address

"Optimization" of the operating system

Set the OS settings to performance mode

Use the cpufrequtils utility.

sudo apt install cpufrequtils

By default, after installing Ubuntu, the “ondemand” mode is used (CPU performance is adjusted based on application requests, which saves power but reduces performance):

cat /etc/init.d/cpufrequtils | grep GOVERNOR=

The system output shows that the default mode after installation is “ondemand”:

GOVERNOR="ondemand"

To set the performance mode, in the /etc/init.d/cpufrequtils file, replace ondemand with performance

sudo sed -i 's/GOVERNOR="ondemand"/GOVERNOR="performance"/g' /etc/init.d/cpufrequtils

Restart the utility:

sudo /etc/init.d/cpufrequtils restart 

Then run the following command:

sudo systemctl daemon-reload


Disable SWAP

The Ubuntu SSW server operates in real time, so all necessary data must be stored in RAM; using a swap file (/swap.img) can increase the processing time for SSW ECSS10 application calls, which is unacceptable. Disable swap.
Execute the following three commands one by one:

Disable Swap:

sudo swapoff -a

Delete the swap.img file.

sudo rm /swap.img

Comment out the line — /swap.img none swap sw 0 0 — in the /etc/fstab file by running the sudo nano /etc/fstab command

or change it to # /swap.img none swap sw 0 0

or delete this string (/swap.img none swap sw 0 0)

sudo nano /etc/fstab

To verify, run the free -h command:

free -h

Swap size equals 0, which means it's disabled

free -h
              total        used        free      shared  buff/cache   available
Mem:           3,9G        110M        3,2G        820K        535M        3,5G
Swap:            0B          0B          0B

Setting the timezone

During the installation of Ubuntu 22, you are not prompted to set a time zone (the default is UTC). You must set it manually (to ensure the billing system, scheduled tasks, etc., function correctly), for example:

sudo timedatectl set-timezone Asia/Novosibirsk

Improving the performance of high-load servers

You can improve the performance of high-load servers by increasing the open file limit.

To set the open file limit, do the following:

Check the current limit using the command:

ulimit -a

The output:

eltex@ecss1:~$ ulimit -a
core file size          (blocks, -c) 0
data seg size           (kbytes, -d) unlimited
scheduling priority             (-e) 0
file size               (blocks, -f) unlimited
pending signals                 (-i) 15515
max locked memory       (kbytes, -l) 65536
max memory size         (kbytes, -m) unlimited
open files                      (-n) 1024
pipe size            (512 bytes, -p) 8
POSIX message queues     (bytes, -q) 819200
real-time priority              (-r) 0
stack size              (kbytes, -s) 8192
cpu time               (seconds, -t) unlimited
max user processes              (-u) 15515
virtual memory          (kbytes, -v) unlimited
file locks                      (-x) unlimited

This limit (open files 1024) is not enough for normal operation of high-load servers.

Set the open file limit for each user:

sudo sed -i  '55i\*                soft    nproc           65536\n*                hard    nproc           131072\n*                soft    nofile          65536\n*                hard    nofile          131072\nroot             -       memlock         unlimited' /etc/security/limits.conf

# /etc/security/limits.conf
#
#Each line describes a limit for a user in the form:
#
#<domain>        <type>  <item>  <value>
#
#Where:
#<domain> can be:
#        - a user name
#        - a group name, with @group syntax
#        - the wildcard *, for default entry
#        - the wildcard %, can be also used with %group syntax,
#                 for maxlogin limit
#        - NOTE: group and wildcard limits are not applied to root.
#          To apply a limit to the root user, <domain> must be
#          the literal username root.
#
#<type> can have the two values:
#        - "soft" for enforcing the soft limits
#        - "hard" for enforcing hard limits
#
#<item> can be one of the following:
#        - core - limits the core file size (KB)
#        - data - max data size (KB)
#        - fsize - maximum filesize (KB)
#        - memlock - max locked-in-memory address space (KB)
#        - nofile - max number of open files
#        - rss - max resident set size (KB)
#        - stack - max stack size (KB)
#        - cpu - max CPU time (MIN)
#        - nproc - max number of processes
#        - as - address space limit (KB)
#        - maxlogins - max number of logins for this user
#        - maxsyslogins - max number of logins on the system
#        - priority - the priority to run user process with
#        - locks - max number of file locks the user can hold
#        - sigpending - max number of pending signals
#        - msgqueue - max memory used by POSIX message queues (bytes)
#        - nice - max nice priority allowed to raise to values: [-20, 19]
#        - rtprio - max realtime priority
#        - chroot - change root to directory (Debian-specific)
#
#<domain>      <type>  <item>         <value>
#

#*               soft    core            0
#root            hard    core            100000
#*               hard    rss             10000
#@student        hard    nproc           20
#@faculty        soft    nproc           20
#@faculty        hard    nproc           50
#ftp             hard    nproc           0
#ftp             -       chroot          /ftp
#@student        -       maxlogins       4
*                soft    nproc           65536
*                hard    nproc           131072
*                soft    nofile          65536
*                hard    nofile          131072
root             -       memlock         unlimited

# End of file


Packages must NOT be installed as the ssw user.

Updating operating system software

  1. To install the ECSS-10 system, you must add the Eltex repository::
    sudo sh -c "echo 'deb [arch=amd64] http://archive.eltex.org/ssw/jammy/3.18 stable main extras external' > /etc/apt/sources.list.d/eltex-ecss10-stable.list"

    Next, import the key using the following command::

    sudo apt-key adv --keyserver keyserver.ubuntu.com --recv-keys 33CB2B750F8BB6A5

    Before the installation, update the OS:

    sudo apt update

    If you see the following system message::

    W: http://archive.eltex.org/ssw/jammy/3.18/dists/stable/InRelease: Key is stored in legacy trusted.gpg keyring (/etc/apt/trusted.gpg), see the DEPRECATION section in apt-key(8) for details.

    Run the following command:

    sudo cp /etc/apt/trusted.gpg /etc/apt/trusted.gpg.d


    sudo apt upgrade


Installing and configuring the software

  ┌ ECSS software version. It is currently listed as 3 in the certification application.. 
  | We will not change it until the next certification or
  │ the release of a fundamentally new version of the system.
  │
  │     ┌ System Release version. The common version for all components included in a specific release. 
  |     | We change it centrally when
  │     │ we decide to release a new version. Releases are typically not compatible with one another.
┌─┴┐ ┌──┴─┐
ECSS.SysRel.SubMaj.SubMin
            └──┬─┘ └──┬─┘
               │      └ Subsystem minor version. The subsystem minor version is set by the subsystem developer. 
               |        The minor version
               │        is updated when a patch is added. As a rule, minor versions within a single major version 
               │        are compatible with each other and differ only within specific patches.
               │
               └ Subsystem major version. The major version is set by the subsystem developer. 
                 The subsystem’s major version must be changed when significant changes are made to the subsystem.


The APT package installation utility analyzes the package version from left to right; for example, if we have package 14.14.7.7  
and the repository contains the following packages
14.14.7.8
14.14.7.9
14.14.8.1
14.14.20 -14.14.28
then when you run the command `sudo apt install package_name`, the package 14.14.28 will be automatically checked and installed, since it is the latest version, the analysis will be performed based on the 3rd position (major), and the analysis based on the 4th position (minor) will not be performed (the sudo apt upgrade command will be performed in the same way).

If, in a specific situation, you need to upgrade from version 14.14.7.7 to version 14.14.7.9, the standard command → sudo apt upgrade won’t work, since it will select the newest package. In this situation, we need to explicitly specify which version of the package we want to install; in this example, we should use the command → sudo apt install package_name=14.14.7.9. This is usually necessary for testing a specific patch; for standard updates, simply using the usual command to install or update the package is sufficient.


Install all the offered packages:

sudo apt install ntp ntpdate tcpdump vlan dnsmasq aptitude atop ethtool htop iotop mc minicom mtr-tiny nmap pptpd pv screen ssh tftpd vim sngrep tshark cpanminus gnuplot libgraph-easy-perl debconf-utils wget rsync ncdu

List of required service software:

sudo apt install ntp tcpdump vlan dnsmasq


ntpNTP server
tcpdumppacket sniffer
vlanVLAN management
dnsmasqlightweight DNS/DHCP server

List of recommended diagnostic and utility software:

sudo apt install aptitude atop ethtool htop mc screen ssh tftpd sngrep tshark gnuplot libgraph-easy-perl debconf-utils iotop ncdu


aptitudeinstalls software from repositories; recommended as an alternative to apt/apt-get
atopmonitors host load with the ability to periodically save data to files
ethtooldisplays network interface statistics
htopprocess monitor
mcfile manager
screenterminal multiplexer
sshSSH server and client
tftpdTFTP server
sngrepSIP packet tracer
tsharkconsole-based equivalent of Wireshark
gnuplotplots statistical graphs
libgraph-easy-perlPerl module for converting or rendering graphs (to ASCII, HTML, SVG, or via Graphviz)
debconf-utilsa set of utilities for working with the debconf database
iotopa tool for monitoring disk I/O usage in real time on Linux
ncdua utility for searching large directories on a Linux system


This software is not required for the ECSS-10 system to operate, but it can simplify maintenance of the system and its individual components by operations and technical support engineers.


Before installing the ecss packages, you must ensure that the SPD bandwidth meets the necessary requirements.
To do this, run the sudo ethtool <interface name> command for all physical interfaces.

sudo ethtool net.20
Settings for net.20:
    Supported ports: [ TP ]
    Supported link modes:   10baseT/Half 10baseT/Full
                            100baseT/Half 100baseT/Full
                            1000baseT/Full
    Supported pause frame use: No
    Supports auto-negotiation: Yes
    Supported FEC modes: Not reported
    Advertised link modes:  10baseT/Half 10baseT/Full
                            100baseT/Half 100baseT/Full
                            1000baseT/Full
    Advertised pause frame use: No
    Advertised auto-negotiation: Yes
    Advertised FEC modes: Not reported
    Speed: 1000Mb/s
    Duplex: Full
    Auto-negotiation: on
    Port: Twisted Pair
    PHYAD: 0
    Transceiver: internal
    MDI-X: off (auto)
    Link detected: yes

Check the values of the following parameters:
Advertised auto-negotiation: Yes
Speed: 1000Mb/s (at least)
Duplex: Full


Configuring the ecss-dns-env package

Execute the following command:

sudo apt install -y ecss-dns-env

The configurator will prompt you to select the sections to configure based on the questions below. Select a broker. (For example, 10.0.10.51).

ecss-dns-env questionAnswers for ecss1 
[Primary broker] Enter the address ([Primary broker] Enter ip)10.0.10.51 (needs to be entered)


[Secondary broker] Enter the address ([Secondary broker] Enter ip)10.0.10.51 (needs to be entered)



If there will be a need to adjust the IP addresses later, use the following command: 

sudo dpkg-reconfigure ecss-dns-env


Installing Postgres

Before installing ecss-postgres-bdr-sswdocker should be added to apt sources. To do that, run the following commands:

sudo install -m 0755 -d /etc/apt/keyrings
sudo curl -fsSL https://download.docker.com/linux/ubuntu/gpg -o /etc/apt/keyrings/docker.asc
sudo chmod a+r /etc/apt/keyrings/docker.asc
sudo sh -c "echo 'deb [arch=amd64 signed-by=/etc/apt/keyrings/docker.asc] https://download.docker.com/linux/ubuntu   jammy stable' >> /etc/apt/sources.list.d/docker.list"
sudo apt update && sudo apt upgrade

Installing the ecss-postgres-bdr-ssw package

Install the ecss-postgres-bdr-ssw package:

sudo apt install ecss-postgres-bdr-ssw

When configuring the ecss-postgres-bdr-ssw package, the following questions will be asked:

ecss-postgres-bdr-ssw questionsAnswers for ecss1Example
Current IP address of the network interface 
(Select the address used earlier by MySQL).
Select an IP address for working with Postgres from the list


Install on a cluster?No (needs to be selected)


. . .
==================
 Create databases 
==================
CREATE DATABASE
CREATE DATABASE
CREATE EXTENSION
CREATE EXTENSION
===================================
 Creating Postgres Exporter Schema 
===================================
Node IP: localhost
CREATE SCHEMA
GRANT
CREATE FUNCTION
CREATE VIEW
GRANT
CREATE FUNCTION
CREATE VIEW
GRANT
CREATE EXTENSION
CREATE FUNCTION
CREATE VIEW
GRANT
=======================================================
=======================================================
 ecss-postgres-bdr-ssw successfully installed/updated! 
=======================================================
=======================================================
┏┓┏┓┏┓┏┳┓┏┓┳┓┏┓┏┓  ┳┓┳┓┳┓  ┏┓┏┓┓ ┏
┃┃┃┃┗┓ ┃ ┃┓┣┫┣ ┗┓  ┣┫┃┃┣┫  ┗┓┗┓┃┃┃
┣┛┗┛┗┛ ┻ ┗┛┛┗┗┛┗┛  ┻┛┻┛┛┗  ┗┛┗┛┗┻┛


No additional actions are necessary for this step.

Install the License Provider package:

sudo apt install ecss-license-provider

When istalling the ecss-license-provider package, the following questions will be asked:

QuestionsAnswersExamples

License Provider listen ip:

0.0.0.0 (default value)

License Provider listen port:4321 (default value)

Log level:info (default value),
possible options: debug, error, info

License Provider cluster key:

specify a unique name
ecss-lm-cluster (default value)

Managers with identical names will try to form a cluster for mutual redundancy.


The data is saved to the /etc/ecss/ecss-license-provider/config.env file:

ECSS_LM_HOST=0.0.0.0
ECSS_LM_PORT=4321
ECSS_LM_LOG_LEVEL=info
RELEASE_COOKIE=ecss-abf-lm-cluster

License Provider (LP) configuration

The ecss-license-provider service uses two configuration files: /etc/ecss/ecss-license-provider/config.env and /etc/ecss/ecss-license-provider/config.yaml.

Information is saved to the config.env file during the ecss-license-provider package installation.

The config.yaml file contains main settings for connecting to the ELM server: where to take licenses from, which licenses to take, and where to send them. All of this should be configured manually.

elm_addresses: []
licenses: []
ecss_nodes: []
To fill in these fields open the ecss-elm-adapter configuration file used in the version 3.17 /etc/ecss/ecss-elm-adapter/config.env:
cat /etc/ecss/ecss-elm-adapter/config.env 
ELM_HOST=elm.eltex-co.ru
ELM_PORT=8099
ECSS_PRODUCT_ID=ECSS2000000
ECSS_LICENSE_KEY=ssw987654
LOG_LEVEL=info
LICENCE_FAIL_TIMER_SECONDS=10
LICENCE_PULL_TIMER_SECONDS=360

It is necessary to specify the ELM servers list to which you wnat to connect to obtain licenses. First address in the list is used as the main one. Additional lines contain backup addresses:
- "elm.eltex-co.ru:8099"
- "192.168.111.22:8099"
- "elm-3.eltex.loc:8099"

Then licenses are specified in the licenses field.

  • The id can be anything, as long as it is unique for each license. It only affects the license address on the License Provider itself (e.g., 0, 1, 2, 3).
  • kind. For SSW, only SSW (in uppercase) is supported.
  • type is set to elm if this license is to be requested from the ELM server. If you need to use an SSW file-based license, set the type to ecss_license.
    • for the elm type, you must specify the license_key and product_id fields to identify the license.
    • for the ecss_license type, specify the license field containing the static license key.

The license_key = ECSS_LICENSE_KEY and product_id = ECSS_PRODUCT_ID parameters must match the data previously uploaded to the ELM server.

The ecss_nodes block.

This block must specify the details of the services that will receive the license. A service is specified by three parameters:

  • id - the service identifier. For SSW, this must match the ECSS_ID of the SSW being licensed.
  • kind - the type of service being licensed. Similar to the licenses block, the SSW and AUP types are supported. For SSW, only SSW is supported.
  • license_id - the identifier of the license that will be sent to this service. It corresponds to the license identifiers from the licenses block.
Two SSWs with different ECSS_IDs cannot receive the same license; a configuration with such an assignment will be marked as invalid
In addition, two SSWs with the same ECSS_ID cannot simultaneously obtain the same license from a single License Provider; therefore, it is extremely important to set your ECSS_ID correctly and ensure that it is unique, at least within the scope of the License Provider you are using.

The ECSS_ID specified in the /etc/ecss/ecss-license-provider/config.yaml file must match the ECSS_ID (ECSS node identifier) that you specify when installing the ecss-node package

When updating, be sure to specify a new ECSS node name (ECSS_ID) that is different from the old ECSS node name. Otherwise, if the names match, the ecss-mycelium service will not be enabled.


ECSS_ID format.
It must begin and end with a Latin letter or number; periods and dashes may be used within the text. 

[A-Za-z0-9][A-Za-z0-9.-][A-Za-z0-9]
elm_addresses:
 - "elm.eltex-co.ru:8099"
licenses:
 - id: 0
   kind: SSW
   type: elm
   license_key: "ssw987654"
   product_id: "ECSS2000000"
ecss_nodes:
 - id: test.update
   kind: ssw
   license_id: 0

Restart the ecss-license-provider.service service for updating configuration from the /etc/ecss/ecss-license-provider/config.yaml file using the following command:

sudo systemctl restart ecss-license-provider.service


Installing ecss-node

Installing the required ecss-node package includes the installation and initial configuration of the core subsystems.

The ecss-postgres-bdr-ssw package must already be installed on the system

To install the ecss-node package, run the following command:

sudo apt install -y ecss-node

During installation, a user named ssw is created, under whose account all ecss* services are run. The necessary directories are created, DNS configuration is performed, and SSL certificates are configured.

The ecss-user package will also be installed during this process

During installation, you will be prompted to configure the parameters needed to generate the configuration files; examples of responses are provided below.

ecss-user questionsAnswers for ecss1Example

Do you want to use the default settings?


Yes (default value)

 
ecss-node questionsAnswers for ecss1Example

ECSS node identifier in DNS format (cluster name configuration): (any unique name; test.update is used in the example)

When updating, the name of the new ECSS node must be different from that of the old ECSS node. Otherwise, if the names match, the ecss-mycelium service will not be enabled.

The ECSS node identifier must match the ECSS_ID specified in the license provider’s configuration file – /etc/ecss/ecss-license-provider/config.yaml.

 

test.update (needs to be entered)

ECSS_ID format:
Must begin and end with a Latin letter or digit; periods and hyphens may be used in the middle. 

[A-Za-z0-9][A-Za-z0-9.-][A-Za-z0-9]

Do you want to use the default settings?Yes (default value)

 
ecss-user questionsAnswers for ecss1Example
Maximum size of an uncompressed core dump in bytes.8G (default value)

Maximum size of a compressed core dump in bytes.2G (default value)

Maximum size that the /var/lib/systemd/coredump directory can occupy:

default (default value)

Minimum amount of free disk space in bytes. 30G (default value)

Save the /etc/ecss/ssl/ecss10root.key file to a safe location and delete it!

Ok (default value)

Cookie for the core node:

ecss-core (needs to be entered)


Cookie for the ds node:

ecss-ds (needs to be entered)


Cookie for the mediator node: 

ecss-mediator  (needs to be entered)


Cookie for the pa-sip node: 

ecss-pa-sip  (needs to be entered)


Cookie for the mycelium node:

ecss-mycelium (needs to be entered)


To check the NTP synchronization status, use the `ntpq -p` command. If you use the additional `-n` option, the IP address will be displayed instead of the server name:

ntpq -p
     remote           refid      st t when poll reach   delay   offset  jitter
==============================================================================
*185.125.190.56  17.253.28.253    2 u   45   64    1   83.893   +0.470   2.177

Stop the following services::

sudo systemctl stop ecss-core ecss-pa-sip ecss-ds ecss-mediator ecss-mycelium

Create a backup for oasys (Copy Mnesia database from old to new ecss1), run the following commands:

cd /var/lib/ecss/oasys/
sudo rsync -a <Your_user>@<IP_add_of_an_old_server>:/var/lib/ecss/oasys/Mnesia.ds1@ecss1/ Mnesia.ds1@ecss1/
sudo rsync -a <Your_user>@<IP_add_of_an_old_server>:/var/lib/ecss/oasys/Mnesia.md1@ecss1/ Mnesia.md1@ecss1/
cd ~


Restart the SSW services:

sudo systemctl restart ecss-core ecss-pa-sip ecss-ds ecss-mediator ecss-mycelium

To check the status of the services, run the system-status command in CoCon:

/system-status 
Checking...
┌─┬───────────────┬─────────────────────────┬───────────────┬────────────┬──────┐
│ │     Node      │         Release         │ Erlang nodes  │Mnesia nodes│Uptime│
├─┼───────────────┼─────────────────────────┼───────────────┼────────────┼──────┤
│ │core1@ecss1    │ecss-core-3.18.0.271     │core1@ecss1    │not running │3m 55s│
│ │ds1@ecss1      │ecss-ds-3.18.0.271       │ds1@ecss1      │ds1@ecss1   │4m 40s│
│ │md1@ecss1      │ecss-mediator-3.18.0.271 │md1@ecss1      │md1@ecss1   │3m 50s│
│ │mycelium1@ecss1│ecss-mycelium-3.18.0.271 │mycelium1@ecss1│not running │5m 28s│
│ │sip1@ecss1     │ecss-pa-sip-3.18.0.271   │sip1@ecss1     │sip1@ecss1  │3m 45s│
│ │sorm1@ecss1    │ecss-sorm-3.18.0.271     │sorm1@ecss1    │not running │1m 55s│
└─┴───────────────┴─────────────────────────┴───────────────┴────────────┴──────┘

Licensing modes.

File-based licensing

No additional actions are necessary.

/cluster/storage/ds1/licence/list-licence
┌──┬───────────────────┬────────────────┬──────┬────────────────────────────────────────────┬────────────────────┬────────────┐
│Id│Creation date(UTC) │     SSW ID     │Active│                Description                 │Expiration date(UTC)│ Time left  │
├──┼───────────────────┼────────────────┼──────┼────────────────────────────────────────────┼────────────────────┼────────────┤
│1 │31.10.2025 14:16:00│ECSS 010070     │*     │Eltex SC softswitch                         │31.12.2026 23:59:59 │224d 21h 31m│
│0 │                   │ECSS DEFAULT    │      │Default licence                             │                    │            │
└──┴───────────────────┴────────────────┴──────┴────────────────────────────────────────────┴────────────────────┴────────────┘

ELM service licensing

Configure the SSW connection to the License Provider using the following command in CoCon (in this example, the License Provider is installed on the ecss1 host, hosts IPadd is 10.0.10.51. Port value from the /etc/ecss/ecss-license-provider/config.env file is 4321 by default):

/system/licence/manager/set --hosts [https://10.0.10.51:4321]

After execution, check the connection status with the following command:

/system/licence/manager/show-status
┌───────────────────────┬───────┬─────┐
│         Host          │Current│Alive│
├───────────────────────┼───────┼─────┤
│https://10.0.10.51:4321│*      │true │
└───────────────────────┴───────┴─────┘

The host should have the alive=true status and be "current". 

  • Current - indicates which host the SSW is connected to. If there is a connection, * is displayed; if not, nothing is displayed.
  • Alive - displays the host’s availability status (healthcheck).

A lack of connection to the License Provider or ELM is equivalent to a lack of access to the token, which will lead to critical failures and a transition to emergency mode; after a certain period, if the connection is not restored, the system will switch to the Default license.

This behavior applies only when operating in ELM mode.

If the status for one of the License Provider hosts is shown as “current,” you can send a request to upload the license to the SSW using the following command:

/cluster/storage/ds1/licence/request
/cluster/storage/ds1/licence/request      
Licence received      
[*******                                                               ] 6s 2ms   
Success: Licence parameters applied
/cluster/storage/ds1/licence/list-licence 
┌──┬───────────────────┬────────────┬──────┬────────────────┬────────────────────┬────────────────────┬─────────┐
│Id│Creation date(UTC) │   SSW ID   │Active│  Description   │Comm. Exp. Date(UTC)│Expiration date(UTC)│Time left│
├──┼───────────────────┼────────────┼──────┼────────────────┼────────────────────┼────────────────────┼─────────┤
│1 │14.04.2026 11:18:34│ECSS2000000 │*     │ECSS ELM License│09.04.2027 16:26:34 │06.06.2026 10:49:12 │1d 6h 59m│
│0 │01.01.1990 00:00:00│ECSS DEFAULT│      │Default licence │                    │                    │         │
└──┴───────────────────┴────────────┴──────┴────────────────┴────────────────────┴────────────────────┴─────────┘


Installing ecss-restfs, ecss-media-server, ecss-web-conf packages

Next, install the ecss-restf package, followed by ecss-media-server, ecss-media-resources, ecss-web-conf, and others in any order:

ecss-restfs

sudo apt install -y ecss-restfs

Installing ecss-restfs.  

When installing the ecss-restfs package, you will be prompted to specify configuration options. The answers to these questions are provided below.

ecss-restfs questionsAnswers

Use TTS service

No (default value)

Configure phone book

No (default value)

Configure speech recognition service

No (default value)

Select nothing

Ok

After installing the ecss-restfs package, check for the presence of the voice guide’s WAV files in the /var/lib/ecss/restfs/system/sounds/ directory using the command:

ll /var/lib/ecss/restfs/system/sounds/

The presence of WAV files in the directory specified above indicates that the ecss-restfs package was installed correctly

The absence of WAV files in the directory specified above indicates a problem with the installation of the ecss-restfs package. To resolve this, run the following command:

sudo apt --fix-broken install 

and repeat the verification command:

ll /var/lib/ecss/restfs/system/sounds/


Next, you need to make sure that these files are accessible from outside. To do so, run the following command: Installing ecss-restfs.

wget http://ecss1:9990/system/sounds/ai_you.wav

 

wget http://ecss1:9990/system/sounds/ai_you.wav
--2026-04-18 17:43:29--  http://ecss1:9990/system/sounds/ai_you.wav
Resolving ecss1 (ecss1)... 127.0.1.1, 10.0.10.51
Connecting to ecss1 (ecss1)|127.0.1.1|:9990... connected.
HTTP request sent, awaiting response... 200 OK
Length: 11670 (11K) [audio/x-wav]
Saving to: ‘ai_you.wav’

ai_you.wav                                  100%[========================================================================================>]  11,40K  --.-KB/s    in 0s      

2026-04-18 17:43:29 (301 MB/s) - ‘ai_you.wav’ saved [11670/11670]

You can delete the test file

rm ai_you.wav

Transfer the call recordings from the old server to the new one by running the following command:

sudo rsync -a <your_user>@<IP_add_of_an_old_ecss1>:/var/lib/ecss/restfs/domain/ /var/lib/ecss/restfs/domain/


abf@ecss1:/var/lib/ecss/restfs/domain$ ls -la /var/lib/ecss/restfs/domain
8 total
drwxr-xr-x 2 www-data www-data 4096 apr 22 18:21 .
drwxr-xr-x 7 www-data www-data 4096 may 28 15:07 ..

abf@ecss1:/var/lib/ecss/restfs/domain$ sudo rsync -a abf@10.0.10.10:/var/lib/ecss/restfs/domain/ /var/lib/ecss/restfs/domain/

abf@ecss1:/var/lib/ecss/restfs/domain$ ls -la test_domain/records/2026_05_28
610 total
drwxrwxrwx 2 www-data www-data  4096 may 28 14:56 .
drwxrwxrwx 3 www-data www-data  4096 may 28 14:27 ..
-rw-r--r-- 1 www-data www-data 71892 may 28 14:27 2026-05-28_14-27-02_t_42009-42007.pcm
-rw-rw-rw- 1 www-data www-data    86 may 28 14:27 2026-05-28_14-27-02_t_42009-42007.pcm.meta
-rw-r--r-- 1 www-data www-data 71892 may 28 14:31 2026-05-28_14-31-19_o_42007-42009.pcm
-rw-rw-rw- 1 www-data www-data    86 may 28 14:31 2026-05-28_14-31-19_o_42007-42009.pcm.meta
-rw-r--r-- 1 www-data www-data 63904 may 28 14:55 2026-05-28_14-55-24_o_42007-42009.pcm
-rw-rw-rw- 1 www-data www-data    86 may 28 14:55 2026-05-28_14-55-24_o_42007-42009.pcm.meta
-rw-r--r-- 1 www-data www-data 39940 may 28 14:55 2026-05-28_14-55-31_o_42007-42009.pcm
-rw-rw-rw- 1 www-data www-data    86 may 28 14:55 2026-05-28_14-55-31_o_42007-42009.pcm.meta
-rw-r--r-- 1 www-data www-data 15976 may 28 14:55 2026-05-28_14-55-37_o_42007-42009.pcm
-rw-rw-rw- 1 www-data www-data    86 may 28 14:55 2026-05-28_14-55-37_o_42007-42009.pcm.meta
-rw-r--r-- 1 www-data www-data 79880 may 28 14:55 2026-05-28_14-55-48_o_42007-42009.pcm
-rw-rw-rw- 1 www-data www-data    86 may 28 14:55 2026-05-28_14-55-48_o_42007-42009.pcm.meta
-rw-r--r-- 1 www-data www-data 55916 may 28 14:56 2026-05-28_14-55-59_o_42007-42009.pcm
-rw-rw-rw- 1 www-data www-data    86 may 28 14:55 2026-05-28_14-55-59_o_42007-42009.pcm.meta
-rw-r--r-- 1 www-data www-data 47928 may 28 14:56 2026-05-28_14-56-04_o_42007-42009.pcm
-rw-rw-rw- 1 www-data www-data    86 may 28 14:56 2026-05-28_14-56-04_o_42007-42009.pcm.meta
-rw-r--r-- 1 www-data www-data 31952 may 28 14:56 2026-05-28_14-56-28_t_42009-42007.pcm
-rw-rw-rw- 1 www-data www-data    86 may 28 14:56 2026-05-28_14-56-28_t_42009-42007.pcm.meta
-rw-r--r-- 1 www-data www-data 31952 may 28 14:56 2026-05-28_14-56-37_t_42009-42007.pcm
-rw-rw-rw- 1 www-data www-data    86 may 28 14:56 2026-05-28_14-56-37_t_42009-42007.pcm.meta
-rw-r--r-- 1 www-data www-data 95856 may 28 14:56 2026-05-28_14-56-42_t_42009-42007.pcm
-rw-rw-rw- 1 www-data www-data    86 may 28 14:56 2026-05-28_14-56-42_t_42009-42007.pcm.meta

ecss-media-server

sudo apt install -y ecss-media-server

For the media server (ecss-media-server/MSR), you can perform the initial setup by writing the parameters to a configuration file, 
to do this, you need to configure transport bind-addr, mcc bind-address:
Specify the IP address of the old SSW version 3.17 (10.0.20.41 in the example).

ecss-media-server questionsAnswers for ecss1
[ MSR SIP ] Enter the bind-ip address (Enter)10.0.20.41 (needs to be entered)
[MSR Control-Channel] Enter the bind-ip address10.0.20.41 (needs to be entered)


After generating the default configurations, run the following check:

cat /etc/ecss/ecss-media-server/config.xml


Inside is the configuration for msr: config.xml; in the conf.d directory is the default.xml configuration.

Essentially, default.xml is an extension of config.xml that defines the accounts section. This is done to ensure that this configuration remains unchanged after package updates.

<?xml version="1.0" encoding="utf-8"?>
<config date="09:24:23 03.12.2025">
  <general log-level="3" log-rotate="yes" max-calls="2148" max-vid-calls="100" max-in-group="512" load-sensor="media" load-delta="10" calls-delta="100" spool-dir-size="100M" log-name="msr.log" log-path="/var/log/ecss/media-server" use-srtp="disabled" enable-ice-transport="no" ice-update="no" aggressive-ice="yes" stun-server="" suspicious-mode="no"/>
  <transport bind-addr="10.0.20.41" port="5040" transport="udp+tcp"/>
  <!-- By default configured public TURN-server -->
  <turn-server use-turn="no" host="numb.viagenie.ca" user="webrtc@live.com" password="muazkh"/>
  <media mixer-clock-rate="8000" use-vad="no" cng-level="0" jb-size="60" rtcp-timeout="0" rtp-timeout="350" udp-src-check="no" cn-multiplier="3" port-start="12000" port-range="4496" tias-in-sdp="no" thread-cnt="2" vid-enc-threads="2" vid-dec-threads="2" video-conf-layout="evenly" keyframe-interval="1000" vid-decode-delay="100" silent-codec-switch="yes" silence-threshold="-30" dtmf-flash-disable="no" video-dscp="0" other-dscp="0" dummy-video-src="/usr/share/ecss-media-server/video/dummy_video.yuv" video-enc-width="640" video-enc-height="360" finalsilence="1000" rtcp-stat-dump="yes" dtmf-tg-fpc-loop="10" dtmf-tg-fit="1" dtmf-tg-fot="2" dtmf-tg-volume="12288"/>
  <codec pcma="1" pcmu="2" ilbc="0" gsm="0" g722="3" g726="0" g729="0" speex="0" l16="0" g7221="0" opus="0" h264="1" h263-1998="2" t38="1" tel-event-pt="0"/>
  <accounts>
    <!-- <dynamic msr_name="msr.name"
            realm="sip:127.0.0.1:5000"
            dtmf_mode="rfc+inband+info"
            auth_name="user"
            auth_password="password" /> -->
  </accounts>
  <pbyte>
    <mcc bind-addr="10.0.20.41" port="5700"/>
  </pbyte>
  <conf_dir path="/etc/ecss/ecss-media-server/conf.d"/>
  <metrics enable="yes" use-pushgateway="yes" pushgateway-addr="127.0.0.1:9091" push-interval="5" port="8100" msr_name="msr2"/>
  <rtp>
    <auto addr-v4=""/>
  </rtp>
</config>

By default, after installation, ECSS-10 enables only the following codecs: pcma, pcmu, g722, h264, h263-1998, and t38. The rest have a status of 0 (disabled). If you want to enable the remaining codecs, use the nano editor to change the priority from 0 to the desired priority number (the priority level must not be duplicated for the audio/video/fax service).
sudo nano /etc/ecss/ecss-media-server/config.xml

To enable all codecs 
the line: 
<codec pcma="1" pcmu="2" ilbc="0" gsm="0" g722="3" g726="0" g729="0" speex="0" l16="0" g7221="0" opus="0" h264="1" h263-1998="2" t38="1" tel-event-pt="0"/>
should be changed to: 
<codec pcma="1" pcmu="2" ilbc="6" gsm="4" g722="3" g726="11" g729="5" speex="7" l16="8" g7221="9" opus="10" h264="1" h263-1998="2" t38="1" tel-event-pt="0"/>


It is not allowed to specify the same priority for different codecs; for example, g722="5" g729="5". In this case, they will not work correctly or will be ignored.
The exception is “0” – which means disabled.

Take a look at the accounts section (the default.xml file):

cat /etc/ecss/ecss-media-server/conf.d/default.xml

Check the correctness of the data.

<?xml version="1.0"?>
<config>
    <accounts>
        <dynamic msr_name="msr.ecss1" realm="sip:10.0.20.41:5000" dtmf_mode="rfc+inband+info" auth_name="user" auth_password="password">
            <via dynamic-ifaces="no">
                <iface name="net.20" ip="10.0.20.41"/>
            </via>
        </dynamic>
    </accounts>
</config>

It specifies the current settings used to register the MSR on the core.

The main parameters here are msr_name and realm:

After modifying the /etc/ecss/ecss-media-server/config.xml and /etc/ecss/ecss-media-server/conf.d/default.xml configuration files, you should restart the ecss-media-server service for the changes to take effect using the following command:

sudo systemctl restart ecss-media-server

You will see the following message:

Job for ecss-media-server.service failed because the control process exited with error code.
See "systemctl status ecss-media-server.service" and "journalctl -xeu ecss-media-server.service" for details.

The operational IP addresses for the media service are specified, but they are currently still assigned to the old ecss1. After switching the IP addresses, the service will start automatically.


ecss-web-conf

sudo apt install ecss-web-conf

The web configurator makes system management more intuitive and convenient. Installing the web configurator is not required, but it is recommended.
Additionally, installing the ecss-web-conf package automatically installs the ecss-subscriber-portal-ui package. The ECSS-10 system’s “Subscriber Portal” application allows system subscribers to independently manage services, view information on completed calls and active conferences, and configure their own IVR scripts for incoming calls.

ecss-web-conf questionsAnswers for ecss1Example
Do you want to use the default settings?Yes (default value)

Check whether you can connect to the web interface at http://10.0.10.51; the username and password are admin/password. Not all features will be available at this time, but the web interface should work, and you should be able to log in successfully.

Disabling SSW version 3.17

To disable the old SSW version 3.17, run the following commands:
Stopping services

sudo systemctl mask --now ecss-ds ecss-mycelium ecss-mediator ecss-core ecss-pa-sip ecss-sorm

Copying the Postgres database

Copy the Postgres database from the old ecss1 server by running the following command:

sudo tar -Pcvf /tmp/postgres.tar /srv/ecss/ecss-postgres-bdr-ssw/volumes/

Copy postgres.tar to the new server by running the following command:

 scp /tmp/postgres.tar <your_user>@<IP_address_of_a_new_ecss1>:/tmp/postgres.tar

Stop the Postgres database Docker with the following command:

sudo docker compose -f /srv/ecss/ecss-postgres-bdr-ssw/docker-compose.container.yml stop

Clear the /srv/ecss/ecss-postgres-bdr-ssw/volumes subdirectory:

sudo rm -R /srv/ecss/ecss-postgres-bdr-ssw/volumes/*

Extract the Postgres database on the new ecss1 server.

sudo tar xvf /tmp/postgres.tar -C / 

Start the Postgres database Docker with the following command:

sudo docker compose -f /srv/ecss/ecss-postgres-bdr-ssw/docker-compose.container.yml start

Replacing IP addresses on the old ecss1

Change the 10.0.10.41/10.0.20.41 IP addresses to the ones that aren't used in the network (10.0.10.61/10.0.20.61, for example):

sudo nano /etc/netplan/ecss.yaml
network:
  version: 2
  renderer: networkd
  ethernets:
    enp0s3: # Name of a virtual machine interface connected to internet
        dhcp4: yes
        dhcp6: no
    enp0s8: # Name of an interface for SSW
        dhcp4: no # Disable dynamic IP address assignment on the interfaces
        dhcp6: no
        addresses: [192.168.56.41/24]
  vlans:
    net.10: # Management interface
        id: 10
        link: enp0s8
        addresses: [10.0.10.41/24]
        nameservers:
          addresses: [127.0.0.1, 8.8.8.8] # Addresses of DNS servers
    net.20: # Interface for VoIP
        id: 20
        link: enp0s8
        addresses: [10.0.20.41/24]
        routes:
        - to: 10.0.20.128/25
          via: 10.0.20.35
network:
  version: 2
  renderer: networkd
  ethernets:
    enp0s3: # Name of a virtual machine interface connected to internet
        dhcp4: yes
        dhcp6: no
    enp0s8: # Name of an interface for SSW
        dhcp4: no # Disable dynamic IP address assignment on the interfaces
        dhcp6: no
        addresses: [192.168.56.61/24]
  vlans:
    net.10: # Management interface
        id: 10
        link: enp0s8
        addresses: [10.0.10.61/24]
        nameservers:
          addresses: [127.0.0.1, 8.8.8.8] # Addresses of DNS servers
    net.20: # Interface for VoIP
        id: 20
        link: enp0s8
        addresses: [10.0.20.61/24]
        routes:
        - to: 10.0.20.128/25
          via: 10.0.20.35
sudo netplan apply

Switching the new SSW to operational IP addresses

Once the operational IP addresses have been removed from the old SSW, you can assign them to the new SSW. Run the following command:

sudo nano /etc/netplan/ecss.yaml

Change the IP addresses 10.0.10.51/10.0.20.51 to those used on the network for the SSW (in the example, 10.0.10.41/10.0.20.41):

network:
  version: 2
  renderer: networkd
  ethernets:
    enp0s3: # Name of a virtual machine interface connected to internet
        dhcp4: yes
        dhcp6: no
    enp0s8: # Name of an interface for SSW
        dhcp4: no # Disable dynamic IP address assignment on the interfaces
        dhcp6: no
        addresses: [192.168.56.51/24]
  vlans:
    net.10: # Management interface
        id: 10
        link: enp0s8
        addresses: [10.0.10.51/24]
        nameservers:
          addresses: [127.0.0.1, 8.8.8.8] # Addresses of DNS servers
    net.20: # Interface for VoIP
        id: 20
        link: enp0s8
        addresses: [10.0.20.51/24]
        routes:
        - to: 10.0.20.128/25
          via: 10.0.20.35
network:
  version: 2
  renderer: networkd
  ethernets:
    enp0s3: # Name of a virtual machine interface connected to internet
        dhcp4: yes
        dhcp6: no
    enp0s8: # Name of an interface for SSW
        dhcp4: no # Disable dynamic IP address assignment on the interfaces
        dhcp6: no
        addresses: [192.168.56.41/24]
  vlans:
    net.10: # Management interface
        id: 10
        link: enp0s8
        addresses: [10.0.10.41/24]
        nameservers:
          addresses: [127.0.0.1, 8.8.8.8] # Addresses of DNS servers
    net.20: # Interface for VoIP
        id: 20
        link: enp0s8
        addresses: [10.0.20.41/24]
        routes:
        - to: 10.0.20.128/25
          via: 10.0.20.35
sudo netplan apply

Update an IP address in the /etc/hosts file:

sudo nano /etc/hosts

Update an IP address in the /etc/dnsmasq.d/ecss-broker file:

sudo dpkg-reconfigure ecss-dns-env
/system/licence/manager/set --hosts [https://10.0.10.41:4321]
sudo systemctl restart ecss-ds ecss-mycelium ecss-mediator ecss-core ecss-pa-sip ecss-media-server

After the update is complete, verify that all SSW services are functioning properly.